#!/usr/bin/env bash

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

if [ -z "$1" ]; then
	echo "Need environment to execute script, exiting..."
	exit 1
fi

if [[ ! "$1" =~ ^(localdev|prodsyd)$ ]]; then
    echo "$1 is not an environment, exiting..."
    exit 1
fi

ENVIRONMENT=$1
APPLY_ARG=""

while (( "$#" )); do
  case "$2" in
    --apply)
	  APPLY_ARG="--apply"
      shift 1
      ;;
    --)
      shift
      break
      ;;
    -*|--*=) # unsupported flags
      echo "Error: Unsupported flag $2" >&2
      exit 1
      ;;
 	*)
      shift
      ;;
  esac
done


echo "Beginning filter of RBAC global entities on environment: " ${ENVIRONMENT}

# Create Python Virtual Env and install required packages
virtualenv -p python3 venv3

if [ -d "venv3" ]; then
    . venv3/bin/activate
    echo "Installing pip requirements..."
    pip install -r requirements.txt
else
    exit 1
fi

python filter_global_rbac.py -e ${ENVIRONMENT} ${APPLY_ARG}